search_typeeither "full_text" or "series_id" determining whether the description, title, units, and other information are searched or only the id. Defaults to full text.
realtime_start, realtime_endcharacter string of format "YYYY-MM-DD" determining the real-time period. This is used to find historical series.
limitinteger between 1 and 1000 determining the maximum number of results to return.
offsetNon-negative integer
order_byOne of the following: "search_rank", "series_id", "title", "units", "frequency", "seasonal_adjustment", "realtime_start", "realtime_end", "last_updated", "observation_start", "observation_end", "popularity", or "group_popularity". Default is "search_rank".
sort_orderEither "asc" for ascending or "desc" for descending order.
filter_variableString to filter the results by.
tag_namesString of tag names separated by semicolons for filtering results.
exclude_tag_namesString of tag names separated by semicolons that should not be included.
Each function returns the following information in a data.frame.